@@ -51,13 +51,13 @@ class LoginHandler(ClientBaseHandler):
         login_ip = self.get_remote_ip()
         union_id = ""
         if pt == "wx" and code:
-            invoke_result_data = WeChatHelper.code2_session(code, app_id=config.get_value("app_id"), app_secret=config.get_value("app_secret"))
+            invoke_result_data = WeChatHelper.code2_session(code, app_id=share_config.get_value("app_id"), app_secret=share_config.get_value("app_secret"))
             if invoke_result_data.success == False:
                 return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
             open_id =  invoke_result_data.data["openid"]
             union_id =  invoke_result_data.data.get("unionid","")
         elif pt == "tt" and code:
-            invoke_result_data = TikTokHelper.code2_session(code, anonymous_code, app_id=config.get_value("app_id"), app_secret=config.get_value("app_secret"))
+            invoke_result_data = TikTokHelper.code2_session(code, anonymous_code, app_id=share_config.get_value("app_id"), app_secret=share_config.get_value("app_secret"))
             if invoke_result_data.success == False:
                 return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
             open_id = invoke_result_data.data["openid"]
