@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2022-04-24 15:15:19
-@LastEditTime: 2022-12-13 15:46:09
+@LastEditTime: 2023-02-10 09:42:22
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -20,6 +20,7 @@ from seven_framework.redis import *
 from seven_framework.web_tornado.base_handler.base_api_handler import *
 
 from seven_cloudapp_frame.handlers.filter_base import *
+from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.libs.customize.cryptography_helper import *
 from seven_cloudapp_frame.libs.customize.riskmanage_helper import *
@@ -41,7 +42,7 @@ class FrameBaseHandler(BaseApiHandler):
         :last_editors: HuangJianYi
         """
         dict_param = {}
-        if config.get_value("plat_type", 1) != 4: #如果是web站点，从cookie取
+        if share_config.get_value("plat_type", 1) != 4: #平台类型：1淘宝2微信3抖音4web5京东 如果是web站点，从cookie取
             dict_param["open_id"] = self.get_open_id()
             if not dict_param["open_id"]:
                 dict_param["open_id"] = self.get_user_id()
@@ -67,7 +68,7 @@ class FrameBaseHandler(BaseApiHandler):
             dict_param = self.get_http_log_extra_dict()
             self._build_http_log(dict_param)
             # 记录请求参数明文
-            if config.get_value("log_plain", True) == True and self.is_api_encrypt() == True:
+            if share_config.get_value("log_plain", True) == True and self.is_api_encrypt() == True:
                 self.logging_link_info(f"plain_request_params:{self.json_dumps(self.request_params)}")
 
 
@@ -83,7 +84,7 @@ class FrameBaseHandler(BaseApiHandler):
         return
 
     def set_default_headers(self):
-        allow_origin_list = config.get_value("allow_origin_list")
+        allow_origin_list = share_config.get_value("allow_origin_list")
         if allow_origin_list:
             origin = self.request.headers.get("Origin")
             if origin in allow_origin_list:
@@ -158,8 +159,8 @@ class FrameBaseHandler(BaseApiHandler):
         :Description: 校验是否加密
         :last_editors: HuangJianYi
         """
-        client_encrypt_type = config.get_value("client_encrypt_type", 0)  #客户端加密类型 0-无，1-aes加密
-        server_encrypt_type = config.get_value("server_encrypt_type", 0)  #千牛端或后台加密类型 0-无，1-aes加密
+        client_encrypt_type = share_config.get_value("client_encrypt_type", 0)  #客户端加密类型 0-无，1-aes加密
+        server_encrypt_type = share_config.get_value("server_encrypt_type", 0)  #千牛端或后台加密类型 0-无，1-aes加密
         is_encrypt = False if hasattr(self, "is_encrypt") and self.is_encrypt == False else True
         request_source_type = self._request_source_type()
         if is_encrypt == True and (request_source_type == 2 and server_encrypt_type == 1) or (request_source_type == 1 and client_encrypt_type == 1):
@@ -172,7 +173,7 @@ class FrameBaseHandler(BaseApiHandler):
         :Description: 请求来源类型 0-未知 1-client(客户端) 2-server(服务端)
         :last_editors: HuangJianYi
         """
-        plat_type = config.get_value("plat_type", 1) # 平台类型 1淘宝2微信3抖音4web
+        plat_type = share_config.get_value("plat_type", 1)  # 平台类型
         if plat_type == 4:
             return 1
         uri = self.request.uri
@@ -191,7 +192,7 @@ class FrameBaseHandler(BaseApiHandler):
         invoke_result_data = InvokeResultData()
         self.request_params = {}
         if self.is_api_encrypt() == True:
-            encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
+            encrypt_key = share_config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
             if hasattr(self, "encrypt_key"):
                 encrypt_key = self.encrypt_key
             #当有参数app_id时，优先取app_id，然后在是source_app_id
@@ -200,7 +201,7 @@ class FrameBaseHandler(BaseApiHandler):
             else:
                 app_id = self.get_argument("source_app_id", "", strip=True)
             if not app_id:
-                app_id = config.get_value("app_id")
+                app_id = share_config.get_value("app_id")
             password = str(encrypt_key).replace("1", "l")
             if "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
                 try:
@@ -292,18 +293,18 @@ class FrameBaseHandler(BaseApiHandler):
             if self.is_api_encrypt() == True:
                 if is_close_encrypt == False:
                     dv = SevenHelper.get_random(16)
-                    encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
+                    encrypt_key = share_config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
                     if self.get_argument("app_id", "", strip=True):
                         app_id = self.get_argument("app_id", "", strip=True)
                     else:
                         app_id = self.get_argument("source_app_id", "", strip=True)
                     if not app_id:
-                        app_id = config.get_value("app_id")
+                        app_id = share_config.get_value("app_id")
                     password = str(encrypt_key).replace("1", "l")
                     iv = app_id[0:10] + str(dv)[0:6] if len(str(dv)) >= 6 else ""
                     template_value['data'] = CryptographyHelper.aes_encrypt(self.json_dumps(data), password, iv)
                     template_value['dv'] = dv
-                    if config.get_value("log_plain",True) == True:
+                    if share_config.get_value("log_plain", True) == True:
                         self.logging_link_info(f"plain_response_data:{self.json_dumps(data)}")
                 else:
                     template_value['data'] = data
@@ -398,8 +399,8 @@ class FrameBaseHandler(BaseApiHandler):
         :return app_key, app_secret
         :last_editors: HuangJianYi
         """
-        app_key = config.get_value("app_key")
-        app_secret = config.get_value("app_secret")
+        app_key = share_config.get_value("app_key")
+        app_secret = share_config.get_value("app_secret")
         return app_key, app_secret
 
     def get_user_nick(self):
@@ -412,11 +413,11 @@ class FrameBaseHandler(BaseApiHandler):
         user_nick = self.get_param("nick_name")
         if not user_nick:
             user_nick = self.get_param("user_nick")
-        plat_type = config.get_value("plat_type", 1)  # 平台类型 1淘宝2微信3抖音
+        plat_type = share_config.get_value("plat_type", 1)  # 平台类型
         if plat_type == 1:
             #淘宝小程序 source_app_id在本地环境返回空；在test和online环境返回后端模板id，无论在IDE还是千牛端
             if self.get_param("source_app_id") == "":
-                test_config = config.get_value("test_config",{})
+                test_config = share_config.get_value("test_config",{})
                 user_nick = test_config.get("user_nick","")
         return user_nick
 
@@ -427,10 +428,10 @@ class FrameBaseHandler(BaseApiHandler):
         :last_editors: HuangJianYi
         """
         open_id = self.get_param("open_id")
-        plat_type = config.get_value("plat_type", 1)  # 平台类型 1淘宝2微信3抖音4web
+        plat_type = share_config.get_value("plat_type", 1)  # 平台类型
         if plat_type == 1:
             if self.get_param("source_app_id") == "":
-                test_config = config.get_value("test_config",{})
+                test_config = share_config.get_value("test_config",{})
                 open_id = test_config.get("open_id","")
         return open_id
 
@@ -454,12 +455,12 @@ class FrameBaseHandler(BaseApiHandler):
         :return:
         :last_editors: HuangJianYi
         """
-        test_config = config.get_value("test_config", {})
+        test_config = share_config.get_value("test_config", {})
         user_id = test_config.get("user_id", 0)
         if user_id <= 0:
             cookie_user_id = int(self.get_cookie("user_id", 0))
             cookie_user_id_md5 = self.get_cookie("user_id_md5","")
-            check_user_id_md5 = CryptoHelper.md5_encrypt(str(cookie_user_id), config.get_value("cookie_encrypt_key", "r8C1JpyAXxrFV26V"))
+            check_user_id_md5 = CryptoHelper.md5_encrypt(str(cookie_user_id), share_config.get_value("cookie_encrypt_key", "r8C1JpyAXxrFV26V"))
             if cookie_user_id <= 0 or cookie_user_id_md5 != check_user_id_md5:
                 user_id = 0
             else:
@@ -474,7 +475,7 @@ class FrameBaseHandler(BaseApiHandler):
         :return:
         :last_editors: HuangJianYi
         """
-        user_id_md5 = CryptoHelper.md5_encrypt(str(user_id), config.get_value("cookie_encrypt_key", "r8C1JpyAXxrFV26V"))
+        user_id_md5 = CryptoHelper.md5_encrypt(str(user_id), share_config.get_value("cookie_encrypt_key", "r8C1JpyAXxrFV26V"))
         self.set_cookie("user_id", str(user_id), expires_days=expires_days)
         self.set_cookie("user_id_md5", user_id_md5, expires_days=expires_days)
         self.set_cookie("user_token", UUIDHelper.get_uuid(), expires_days=expires_days)
@@ -490,14 +491,14 @@ class FrameBaseHandler(BaseApiHandler):
         if source_app_id:
             return source_app_id
         source_app_id = self.get_param("source_app_id")
-        plat_type = config.get_value("plat_type", 1)  # 平台类型 1淘宝2微信3抖音
+        plat_type = share_config.get_value("plat_type", 1)  # 平台类型
         if plat_type == 1:
             #淘宝小程序 在IDE上返回前端模板id，无论哪个环境；在千牛端上返回正确的小程序id
-            if source_app_id == config.get_value("client_template_id") or source_app_id == "":
-                test_config = config.get_value("test_config",{})
+            if source_app_id == share_config.get_value("client_template_id") or source_app_id == "":
+                test_config = share_config.get_value("test_config",{})
                 source_app_id = test_config.get("source_app_id","")
         if not source_app_id:
-            source_app_id = config.get_value("app_id")
+            source_app_id = share_config.get_value("app_id")
         return source_app_id
 
     def get_app_id(self):
@@ -509,29 +510,25 @@ class FrameBaseHandler(BaseApiHandler):
         app_id = self.get_param("app_id")
         if app_id:
             return app_id
-        plat_type = config.get_value("plat_type", 1)  # 平台类型 1淘宝2微信3抖音
+        plat_type = share_config.get_value("plat_type", 1)  # 平台类型
         if plat_type == 1:
             if self._request_source_type() == 2:
                 user_nick = self.get_user_nick()
                 if user_nick:
                     store_user_nick = user_nick.split(':')[0]
                     if store_user_nick:
-                        main_user_open_id = self.get_param("main_user_open_id")
                         app_info_model = AppInfoModel(context=self)
                         app_info_dict = app_info_model.get_cache_dict(where="store_user_nick=%s", limit="0,1", field="app_id", params=store_user_nick)
                         if app_info_dict:
                             app_id = app_info_dict["app_id"]
-                            if main_user_open_id !="" and app_info_dict.get("main_user_open_id","") == "":
-                                app_info_model.update_table("main_user_open_id=%s","app_id=%s",params=[main_user_open_id,app_id])
-                                app_info_model.delete_dependency_key()
             elif self._request_source_type() == 1:
                 app_id = self.get_param("source_app_id")
                 #淘宝小程序 在IDE上返回前端模板id，无论哪个环境
-                if app_id == config.get_value("client_template_id") or app_id == "":
-                    test_config = config.get_value("test_config",{})
+                if app_id == share_config.get_value("client_template_id") or app_id == "":
+                    test_config = share_config.get_value("test_config", {})
                     app_id = test_config.get("source_app_id","")
         if not app_id:
-            app_id = config.get_value("app_id")
+            app_id = share_config.get_value("app_id")
         return app_id
 
     def get_access_token(self):
@@ -541,9 +538,9 @@ class FrameBaseHandler(BaseApiHandler):
         :last_editors: HuangJianYi
         """
         access_token = self.get_param("access_token")
-        plat_type = config.get_value("plat_type", 1)  # 平台类型 1淘宝2微信3抖音
+        plat_type = share_config.get_value("plat_type", 1)  # 平台类型
         if plat_type == 1:
-            test_config = config.get_value("test_config",{})
+            test_config = share_config.get_value("test_config", {})
             user_nick = self.get_param("user_nick")
             if user_nick:
                 store_user_nick = user_nick.split(':')[0]
@@ -553,14 +550,29 @@ class FrameBaseHandler(BaseApiHandler):
 
     def get_act_id(self):
         """
-        :description: 获取act_id 如果没传取配置文件的值，配置文件没配置设置默认值1
+        :description: 获取act_id 如果是测试环境，则默认取最新的活动，用于前端测试使用;如果都没有取配置文件的值，配置文件没配置设置默认值1;
         :return int
         :last_editors: HuangJianYi
         """
-        config_act_id = config.get_value("act_id",1)
         act_id = self.get_param_int("act_id",0)
-        if act_id <= 0:
-            act_id = config_act_id
+        if act_id > 0:
+            return act_id
+        app_id = self.get_app_id()
+        env = self.get_param("env") if self.get_param("env") else config.get_value("env","")
+        if env and env != 'online' and app_id:
+            act_info_model = ActInfoModel(context=self)
+            condition_where = ConditionWhere()
+            condition_where.add_condition("app_id=%s and is_release=1")
+            params = [app_id]
+            act_type = self.get_param_int("act_type", 0)
+            if act_type > 0:
+                condition_where.add_condition("act_type=%s")
+                params.append(act_type)
+            act_info_dict = act_info_model.get_cache_dict(where=condition_where.to_string(), order_by="id desc", field="id", params=params)
+            if act_info_dict:
+                act_id = act_info_dict["id"]
+                return act_id
+        act_id = share_config.get_value("act_id", 1)
         return act_id
 
     def create_operation_log(self, operation_type=1, model_name="", handler_name="", old_detail=None, update_detail=None, operate_user_id="", operate_user_name="", operate_role_id="", title="", operation_desc=""):
@@ -580,7 +592,7 @@ class FrameBaseHandler(BaseApiHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        plat_type = config.get_value("plat_type", 1)  # 平台类型 1淘宝2微信3抖音
+        plat_type = share_config.get_value("plat_type", 1)
         if plat_type == 1:
             if not operate_user_id:
                 operate_user_id = self.get_open_id()
@@ -654,7 +666,7 @@ class ClientBaseHandler(FrameBaseHandler):
             # 是否加密模式
             is_api_encrypt = self.is_api_encrypt()
             # 记录请求参数明文
-            if config.get_value("log_plain", True) == True and is_api_encrypt == True:
+            if share_config.get_value("log_plain", True) == True and is_api_encrypt == True:
                 self.logging_link_info(f"plain_request_params:{self.json_dumps(self.request_params)}")
             # 验证超时 10秒过期
             if is_api_encrypt == True:
@@ -676,14 +688,8 @@ class ClientBaseHandler(FrameBaseHandler):
                     self.response_json_error("error", error_message)
                     self.finish()
                     return
-
                 #每分钟流量UV计数,用于登录接口限制登录
                 RiskManageHelper.add_current_limit_count(str(dict_param["app_id"]), str(dict_param["open_id"]))
-            # 校验是否有权限，有才能访问接口
-            if not RiskManageHelper.check_handler_power(self.request_params, self.request.uri, self.__class__.__name__):
-                self.response_json_error("no_power", "没有权限操作")
-                self.finish()
-                return
             # 获取设备信息
             self.device_info_dict = self.get_device_info_dict()
 
