@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2023-01-17 19:00:32
+@LastEditTime: 2023-02-08 14:33:11
 @LastEditors: HuangJianYi
 @Description: 活动模块
 """
@@ -263,7 +263,7 @@ class ActInfoListHandler(ClientBaseHandler):
         act_base_model = ActBaseModel(context=self)
         page_list, total = act_base_model.get_act_info_list(app_id, act_name, is_del, page_size, page_index, False, act_type, is_release)
         for page in page_list:
-            page["online_url"] = app_base_model.get_online_url(page['id'], app_id)
+            page["online_url"] = app_base_model.get_online_url(act_id=page['id'], app_id=app_id, act_type=page['act_type'])
             page["live_url"] = app_base_model.get_live_url(app_id)
         ref_params = {}
         page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
@@ -299,7 +299,7 @@ class ActInfoHandler(ClientBaseHandler):
             act_info_dict["rule_desc_json"] = self.json_loads(act_info_dict["rule_desc_json"]) if act_info_dict["rule_desc_json"] else []
             act_info_dict["agreement_json"] = self.json_loads(act_info_dict["agreement_json"]) if act_info_dict["agreement_json"] else []
             act_info_dict["brand_json"] = self.json_loads(act_info_dict["brand_json"]) if act_info_dict["brand_json"] else {}
-            act_info_dict['online_url'] = app_base_model.get_online_url(act_info_dict['id'], act_info_dict['app_id'])
+            act_info_dict['online_url'] = app_base_model.get_online_url(act_id=act_info_dict['id'], app_id=act_info_dict['app_id'], act_type=act_info_dict["act_type"])
             act_info_dict['live_url'] = app_base_model.get_live_url(act_info_dict['app_id'])
         ref_params = {}
         return self.response_json_success(self.business_process_executed(act_info_dict, ref_params))
