@@ -2,11 +2,12 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 17:00:55
-@LastEditTime: 2022-10-17 13:56:08
+@LastEditTime: 2023-02-10 09:53:17
 @LastEditors: HuangJianYi
 @Description: 基础模块
 """
 
+from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.enum import *
 from seven_cloudapp_frame.models.top_base_model import *
@@ -77,7 +78,7 @@ class SendSmsHandler(ClientBaseHandler):
         sms_type = self.get_param_int("sms_type",2)
         result_code = str(random.randint(100000, 999999))
         if sms_type == 1:
-            sms_ali_config = config.get_value("sms_ali_config",{"host":"","ak":"","secret":"","region_id":"","sign_name":"","template_code":""})
+            sms_ali_config = share_config.get_value("sms_ali_config", {"host": "", "ak": "", "secret": "", "region_id": "", "sign_name": "", "template_code": ""})
             client = AcsClient(sms_ali_config["ak"], sms_ali_config["secret"], sms_ali_config["region_id"])
             request = CommonRequest()
             request.set_accept_format('json')
@@ -100,7 +101,7 @@ class SendSmsHandler(ClientBaseHandler):
             return self.response_json_success()
         else:
             #设置SmsClient的Host，Access Key ID和Secret Access Key
-            sms_bce_config = config.get_value("sms_bce_config",{"host":"","ak":"","sk":"","signature_id":"","template_id":""})
+            sms_bce_config = share_config.get_value("sms_bce_config", {"host": "", "ak": "", "sk": "", "signature_id": "", "template_id": ""})
             sms_config = BceClientConfiguration(credentials=BceCredentials(sms_bce_config["ak"], sms_bce_config["sk"]), endpoint=sms_bce_config["host"])
             #新建SmsClient
             sms_client = sms.SmsClient(sms_config)
