@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 14:11:52
-@LastEditTime: 2022-10-21 11:37:15
+@LastEditTime: 2023-01-04 14:37:44
 @LastEditors: HuangJianYi
 @Description: 订单模块
 """
@@ -110,10 +110,7 @@ class PrizeOrderListHandler(ClientBaseHandler):
         create_date_end = self.get_param("create_date_end")
         order_by = self.get_param("order_by","create_date desc")
         is_search_roster = self.get_param_int("is_search_roster", 0)
-        if is_search_roster == 0:
-            is_search_roster = False
-        else:
-            is_search_roster = True
+        is_search_roster = False if is_search_roster == 0 else True
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
 
@@ -188,9 +185,9 @@ class PrizeRosterListHandler(ClientBaseHandler):
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         order_base_model = OrderBaseModel(context=self)
-        page_info = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end, order_by=order_by, field=field, condition=condition, params=params, is_cache=False)
+        page_list, total= order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end, order_by=order_by, field=field, condition=condition, params=params, is_cache=False)
         ref_params = {}
-        page_info.data = self.business_process_executed(page_info.data, ref_params)
+        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params=ref_params))
         return self.response_json_success(page_info)
 
 
@@ -365,13 +362,13 @@ class PrizeOrderExportHandler(ClientBaseHandler):
         order_base_model = OrderBaseModel(context=self)
         prize_order_list_dict = []
         if page_size <= 500:
-            prize_order_list_dict, prize_order_list_total = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table)
+            prize_order_list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table, page_count_mode='none')
         else:
             max_page_size = 100
             repeat_count = page_size // max_page_size  # 循环次数
             begin_page_index = page_index * repeat_count  # 开始页码
             for i in range(repeat_count):
-                list_dict, list_total = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, max_page_size, begin_page_index + i, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table)
+                list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, max_page_size, begin_page_index + i, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table, page_count_mode='none')
                 if len(list_dict) <= 0:
                     break
                 prize_order_list_dict.extend(list_dict)
@@ -480,13 +477,13 @@ class PrizeRosterExportHandler(ClientBaseHandler):
         order_base_model = OrderBaseModel(context=self)
         prize_roster_list_dict = []
         if page_size <= 500:
-            prize_roster_list_dict = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end, order_by=order_by, field=field, condition=condition, params=params, is_cache=False).data
+            prize_roster_list_dict = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end, order_by=order_by, field=field, condition=condition, params=params, is_cache=False, page_count_mode='none').data
         else:
             max_page_size = 100
             repeat_count = page_size // max_page_size  # 循环次数
             begin_page_index = page_index * repeat_count  # 开始页码
             for i in range(repeat_count):
-                list_dict = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, max_page_size, begin_page_index + i, create_date_start, create_date_end, order_by=order_by, field=field, condition=condition, params=params, is_cache=False).data
+                list_dict = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, max_page_size, begin_page_index + i, create_date_start, create_date_end, order_by=order_by, field=field, condition=condition, params=params, is_cache=False, page_count_mode='none').data
                 if len(list_dict) <= 0:
                     break
                 prize_roster_list_dict.extend(list_dict)
