@@ -8,6 +8,7 @@
 """
 import hashlib
 from seven_framework import *
+from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.models.seven_model import InvokeResultData
 
@@ -29,8 +30,8 @@ class BaidubceHelper:
         :return: 
         :last_editors: HuangJianYi
         """
-        api_key = config.get_value("baidubce_config", {}).get("text_censor",{}).get("api_key","")
-        secret_key = config.get_value("baidubce_config", {}).get("text_censor", {}).get("secret_key","")
+        api_key = share_config.get_value("baidubce_config", {}).get("text_censor", {}).get("api_key", "")
+        secret_key = share_config.get_value("baidubce_config", {}).get("text_censor", {}).get("secret_key", "")
         request_url = f'https://aip.baidubce.com/oauth/2.0/token?grant_type=client_credentials&client_id={api_key}&client_secret={secret_key}'
         response = requests.get(request_url)
         if response:
@@ -87,7 +88,7 @@ class BaidubceHelper:
         """
         :description: 获取百度云存储对象的client客户端
         """
-        baidubce_config = config.get_value("baidubce_config", {}).get("bos", {})
+        baidubce_config = share_config.get_value("baidubce_config", {}).get("bos", {})
         access_key = baidubce_config.get("access_key", "")
         secret_key = baidubce_config.get("secret_key", "")
         end_point = baidubce_config.get("end_point", "")
@@ -116,7 +117,7 @@ class BaidubceHelper:
         :last_editors: HuangJianYi
         """
         bos_client = self.get_bos_client()
-        baidubce_config = config.get_value("baidubce_config", {}).get("bos", {})
+        baidubce_config = share_config.get_value("baidubce_config", {}).get("bos", {})
         folder = baidubce_config.get("folder", "")
         bucket = baidubce_config.get("bucket", "")
         domain = baidubce_config.get("domain", "")
