@@ -2,13 +2,14 @@
 """
 @Author: HuangJianYi
 @Date: 2021-10-22 13:32:07
-@LastEditTime: 2023-01-12 14:54:36
+@LastEditTime: 2023-02-10 09:57:12
 @LastEditors: HuangJianYi
 @Description: 风险控制帮助类
 """
 from seven_framework import *
 from seven_cloudapp_frame.models.seven_model import InvokeResultData
 from seven_cloudapp_frame.libs.customize.seven_helper import *
+from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.models.app_base_model import AppBaseModel
 from seven_cloudapp_frame.models.mp_base_model import MPBaseModel
 import re
@@ -107,7 +108,7 @@ class RiskManageHelper:
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        is_filter_attack = config.get_value("is_filter_attack", False)
+        is_filter_attack = share_config.get_value("is_filter_attack", False)
         if is_filter_attack == True and self.request_params:
             for key in self.request_params.keys():
                 if self.is_contain_sql(self.request_params[key]) or self.is_attack(self.request_params[key]):
