@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2022-10-17 13:47:43
+@LastEditTime: 2023-01-18 16:46:44
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -63,7 +63,7 @@ class ActBaseModel():
                 return None
         return act_info_dict
 
-    def get_act_info_list(self,app_id,act_name,is_del,page_size,page_index,is_cache=True):
+    def get_act_info_list(self, app_id, act_name, is_del, page_size, page_index, is_cache=True, act_type=-1, is_release=-1):
         """
         :description: 获取活动信息列表
         :param app_id: 应用标识
@@ -72,30 +72,41 @@ class ActBaseModel():
         :param page_size: 条数
         :param page_index: 页数
         :param is_cache: 是否缓存
+        :param is_release: 是否发布（1是0否）
         :return: 
         :last_editors: HuangJianYi
         """
         order_by = "id asc"
-        condition = "app_id=%s"
+        condition_where = ConditionWhere()
+        condition_where.add_condition("app_id=%s")
         params = [app_id]
         if is_del !=-1:
-            condition += " and is_del=%s"
+            condition_where.add_condition("is_del=%s")
             params.append(is_del)
+        if is_release !=-1:
+            condition_where.add_condition("is_release=%s")
+            params.append(is_release)
+        if act_type !=-1:
+            condition_where.add_condition("act_type=%s")
+            params.append(act_type)
         if act_name:
-            condition += " and act_name=%s"
+            condition_where.add_condition("act_name=%s")
             params.append(act_name)
+
         if is_cache:
-            page_list, total = ActInfoModel(context=self.context).get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params,dependency_key=DependencyKey.act_info_list(app_id))
+            page_list, total = ActInfoModel(context=self.context).get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params,dependency_key=DependencyKey.act_info_list(app_id))
         else:
-            page_list, total = ActInfoModel(context=self.context).get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params)
+            page_list, total = ActInfoModel(context=self.context).get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params)
         for page in page_list:
             page["share_desc_json"] = SevenHelper.json_loads(page["share_desc_json"]) if page["share_desc_json"] else {}
             page["rule_desc_json"] = SevenHelper.json_loads(page["rule_desc_json"]) if page["rule_desc_json"] else []
+            page["agreement_json"] = SevenHelper.json_loads(page["agreement_json"]) if page["agreement_json"] else []
+            page["brand_json"] = SevenHelper.json_loads(page["brand_json"]) if page["brand_json"] else {}
             page["finish_menu_config_json"] = SevenHelper.json_loads(page["finish_menu_config_json"]) if page["finish_menu_config_json"] else []
             page["finish_status"] = page["is_finish"]
         return page_list, total
 
-    def add_act_info(self,app_id,act_name,act_type,theme_id,share_desc_json,rule_desc_json,close_word="抱歉，程序维护中"):
+    def add_act_info(self, app_id, act_name, act_type, theme_id, share_desc_json, rule_desc_json, close_word="抱歉，程序维护中", is_share=-1, is_rule=-1, is_release=-1, start_date=None, end_date=None, is_black=-1, refund_count=-1, join_ways=-1, is_fictitious=-1, store_url=None, i1=-1, i2=-1, i3=-1, i4=-1, i5=-1, s1=None, s2=None, s3=None, s4=None, s5=None, d1=None, d2=None, is_visit_store=-1, agreement_json=[], brand_json={}):
         """
         :description: 添加活动信息
         :param app_id: 应用标识
@@ -104,7 +115,31 @@ class ActBaseModel():
         :param theme_id: 主题标识
         :param share_desc_json: 分享配置
         :param rule_desc_json: 规则配置
-        :param close_word: 关闭文案
+        :param is_share: 是否开启分享
+        :param is_rule: 是否开启规则
+        :param is_release: 是否发布
+        :param start_date: 开始时间
+        :param end_date: 结束时间
+        :param is_black：是否开启退款惩罚
+        :param refund_count：退款成功次数
+        :param join_ways: 活动参与条件（0所有1关注店铺2加入会员3指定用户）
+        :param is_fictitious: 是否开启虚拟中奖（1是0否）
+        :param store_url: 店铺地址
+        :param i1: i1
+        :param i2: i2
+        :param i3: i3
+        :param i4: i4
+        :param i5: i5
+        :param s1: s1
+        :param s2: s2
+        :param s3: s3
+        :param s4: s4
+        :param s5: s5
+        :param d1: d1
+        :param d2: d2
+        :param is_visit_store: 是否开启访问店铺
+        :param agreement_json: 协议配置（用户协议或隐私条款）
+        :param brand_json: 品牌配置
         :return: 
         :last_editors: HuangJianYi
         """
@@ -132,29 +167,54 @@ class ActBaseModel():
 
         now_datetime = SevenHelper.get_now_datetime()
         act_info_model = ActInfoModel(context=self.context)
-        act_count = act_info_model.get_total("app_id=%s", params=[app_id])
-
+        
         act_info = ActInfo()
         act_info.app_id = app_id
-        act_info.act_name = base_info_dict["product_name"] + "_" + str(act_count + 1) if not act_name else act_name
+        if not act_name:
+            act_count = act_info_model.get_total("app_id=%s", params=[app_id])
+            act_info.act_name = base_info_dict["product_name"] + "_" + str(act_count + 1)
+        else:
+            act_info.act_name = act_name
         act_info.act_type = act_type
         act_info.theme_id = theme_id
         act_info.close_word = close_word
         act_info.share_desc_json = share_desc_json if share_desc_json else {}
         act_info.rule_desc_json = rule_desc_json if rule_desc_json else []
-        act_info.start_date = now_datetime
-        act_info.end_date = "2900-01-01 00:00:00"
+        act_info.start_date = start_date if start_date else now_datetime
+        act_info.end_date =  end_date if end_date else "2900-01-01 00:00:00"
         act_info.task_asset_type_json = act_type_info.task_asset_type_json
-        act_info.is_release = 1
+        act_info.is_release = is_release if is_release != -1 else 1
         act_info.release_date = now_datetime
         act_info.create_date = now_datetime
         act_info.modify_date = now_datetime
+        act_info.is_share = is_share if is_share !=-1 else 0
+        act_info.is_rule = is_rule if is_rule !=-1 else 0
+        act_info.is_black = is_black if is_black != -1 else 0
+        act_info.refund_count = refund_count if refund_count != -1 else 0
+        act_info.join_ways = join_ways if join_ways != -1 else 0
+        act_info.is_fictitious = is_fictitious if is_fictitious != -1 else 0
+        act_info.store_url = store_url if store_url else ''
+        act_info.i1 = i1 if i1 !=-1 else 0
+        act_info.i2 = i2 if i2 !=-1 else 0
+        act_info.i3 = i3 if i3 !=-1 else 0
+        act_info.i4 = i4 if i4 !=-1 else 0
+        act_info.i5 = i5 if i5 !=-1 else 0
+        act_info.s1 = s1 if s1 !=None else ''
+        act_info.s2 = s2 if s2 !=None else ''
+        act_info.s3 = s3 if s3 !=None else ''
+        act_info.s4 = s4 if s4 !=None else ''
+        act_info.s5 = s5 if s5 !=None else ''
+        act_info.d1 = d1 if d1 !=None else '1900-01-01 00:00:00'
+        act_info.d2 = d2 if d2 !=None else '1900-01-01 00:00:00'
+        act_info.is_visit_store = is_visit_store if is_visit_store !=-1 else 0
+        act_info.agreement_json = agreement_json if agreement_json else []
+        act_info.brand_json = brand_json if brand_json else {}
         act_info.id = act_info_model.add_entity(act_info)
         invoke_result_data.data = act_info
         self._delete_act_info_dependency_key(app_id,act_info.id)
         return invoke_result_data
 
-    def update_act_info(self,app_id,act_id,act_name,theme_id,is_share,share_desc_json,is_rule,rule_desc_json,is_release,start_date,end_date,is_black,refund_count,join_ways,is_fictitious,close_word="抱歉，程序维护中",store_url=None,i1=-1,i2=-1,i3=-1,i4=-1,i5=-1,s1=None,s2=None,s3=None,s4=None,s5=None,d1=None,d2=None,is_visit_store=-1):
+    def update_act_info(self, app_id, act_id, act_name, theme_id, is_share, share_desc_json, is_rule, rule_desc_json, is_release, start_date, end_date, is_black, refund_count, join_ways, is_fictitious, close_word="抱歉，程序维护中", store_url=None, i1=-1, i2=-1, i3=-1, i4=-1, i5=-1, s1=None, s2=None, s3=None, s4=None, s5=None, d1=None, d2=None, is_visit_store=-1, agreement_json=[], brand_json={}):
         """
         :description: 修改活动信息
         :param app_id: 应用标识
@@ -168,11 +228,12 @@ class ActBaseModel():
         :param rule_desc_json: 规则配置
         :param start_date: 开始时间
         :param end_date: 结束时间
-        :param close_word: 关闭文案
         :param is_black：是否开启退款惩罚
         :param refund_count：退款成功次数
         :param join_ways: 活动参与条件（0所有1关注店铺2加入会员3指定用户）
         :param is_fictitious: 是否开启虚拟中奖（1是0否）
+        :param close_word: 关闭文案
+        :param store_url: 店铺地址
         :param i1: i1
         :param i2: i2
         :param i3: i3
@@ -186,6 +247,8 @@ class ActBaseModel():
         :param d1: d1
         :param d2: d2
         :param is_visit_store: 是否开启访问店铺
+        :param agreement_json: 协议配置（用户协议或隐私条款）
+        :param brand_json: 品牌配置
         :return: 
         :last_editors: HuangJianYi
         """
@@ -258,6 +321,10 @@ class ActBaseModel():
             act_info.d1 = d1
         if d2 !=None:
             act_info.d2 = d2
+        if agreement_json !=None:
+            act_info.agreement_json = agreement_json
+        if brand_json !=None:
+            act_info.brand_json = brand_json
         act_info.modify_date = now_datetime
         act_info_model.update_entity(act_info,exclude_field_list="finish_menu_config_json,is_finish,task_asset_type_json,is_launch")
         result = {}
