@@ -2,12 +2,13 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2022-11-23 19:00:42
+@LastEditTime: 2023-02-10 10:22:23
 @LastEditors: HuangJianYi
 @Description: 
 """
 from decimal import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
+from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.models.top_base_model import *
 from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.models.db_models.app.app_info_model import *
@@ -159,7 +160,7 @@ class AppBaseModel():
         base_info["product_price_list"] = SevenHelper.json_loads(product_price.content) if product_price else []
         base_info["server_ver"] = base_info_dict["server_ver"]
         base_info["is_force_update"] = base_info_dict["is_force_update"]
-        base_info["is_force_phone"] = config.get_value("is_force_phone",True)
+        base_info["is_force_phone"] = share_config.get_value("is_force_phone",True)
         #中台指定账号升级
         version_info = VersionInfoModel(context=self.context).get_entity(where="type_id=1",order_by="id desc")
         if version_info:
@@ -169,7 +170,7 @@ class AppBaseModel():
                     base_info["client_ver"] = version_info.version_number
         #配置文件指定账号升级
         if user_nick:
-            test_config = config.get_value("test_config",{})
+            test_config = share_config.get_value("test_config",{})
             if user_nick == test_config.get("user_nick",""):
                 base_info["client_ver"] = test_config.get("client_ver","")
         data["base_info"] = base_info
@@ -249,20 +250,25 @@ class AppBaseModel():
             invoke_result_data.data = app_info
             return invoke_result_data
     
-    def get_online_url(self, act_id, app_id, module_id=0):
+    def get_online_url(self, act_id, app_id, module_id=0, act_type=0):
         """
         :description: 获取online_url
         :param act_id:活动标识
         :param app_id:应用标识
         :param module_id:模块标识
-        :param page:跳转的首页地址pages/index/index
+        :param act_type:活动类型
         :return str
         :last_editors: HuangJianYi
         """
         page_index = ""
-        page = config.get_value("page_index")
+        page = share_config.get_value("page_index")
         if page:
-            page_index = "&page=" + CodingHelper.url_encode(page)
+            if isinstance(page,dict):
+                cur_page = page.get(str(act_type),"")
+                if cur_page:
+                    page_index = "&page=" + CodingHelper.url_encode(cur_page)
+            else:
+                page_index = "&page=" + CodingHelper.url_encode(page)
         query = CodingHelper.url_encode(f"actid={act_id}")
         if module_id > 0:
             query = CodingHelper.url_encode(f"actid={act_id}&module_id={module_id}")
