@@ -2,10 +2,11 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2023-02-06 14:34:55
+@LastEditTime: 2023-02-10 10:22:39
 @LastEditors: HuangJianYi
 :description: 
 """
+from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.models.db_models.asset.asset_log_model import *
 from seven_cloudapp_frame.models.db_models.asset.asset_only_model import *
@@ -151,7 +152,7 @@ class AssetBaseModel():
             return invoke_result_data
         #如果only_id已经存在，直接在redis进行拦截,减少数据库的请求，时限1天
         redis_init = SevenHelper.redis_init()
-        is_asset_warn = config.get_value("is_asset_warn",False) #是否开启资产预警，跟控制台配套使用
+        is_asset_warn = share_config.get_value("is_asset_warn",False) #是否开启资产预警，跟控制台配套使用
         only_cache_key = ""
         if only_id:
             only_cache_key = f"asset_only_list:{act_id}_{SevenHelper.get_now_day_int()}"
@@ -375,7 +376,7 @@ class AssetBaseModel():
         user_asset_dict_list = user_asset_model.get_dict_list(condition, params=params)
         if len(user_asset_dict_list) > 0:
             for user_asset_dict in user_asset_dict_list:
-                if config.get_value("is_check_asset",True) == True: #是否开启资产校验
+                if share_config.get_value("is_check_asset",True) == True: #是否开启资产校验
                     if user_asset_dict["app_id"] != str(app_id):
                         user_asset_dict["asset_value"] = 0
                     if self.get_asset_check_code(user_asset_dict["id_md5"], user_asset_dict["asset_value"], app_id) != user_asset_dict["asset_check_code"]:
@@ -399,7 +400,7 @@ class AssetBaseModel():
         user_asset_id_md5 = self.get_user_asset_id_md5(act_id, user_id, asset_type, asset_object_id)
         user_asset_dict = user_asset_model.get_dict("id_md5=%s", limit="1", params=[user_asset_id_md5])
         if user_asset_dict:
-            if config.get_value("is_check_asset",True) == True: #是否开启资产校验
+            if share_config.get_value("is_check_asset",True) == True: #是否开启资产校验
                 if user_asset_dict["app_id"] != str(app_id):
                     user_asset_dict["asset_value"] = 0
                 if self.get_asset_check_code(user_asset_dict["id_md5"], user_asset_dict["asset_value"], app_id) != user_asset_dict["asset_check_code"]:
@@ -768,7 +769,7 @@ class AssetBaseModel():
         store_asset_id_md5 = CryptoHelper.md5_encrypt_int(f"{app_id}_{asset_type}_{asset_object_id}")
         store_asset_dict = store_asset_model.get_dict("id_md5=%s", limit="1", params=[store_asset_id_md5])
         if store_asset_dict:
-            if config.get_value("is_check_asset",True) == True: #是否开启资产校验
+            if share_config.get_value("is_check_asset",True) == True: #是否开启资产校验
                 if store_asset_dict["app_id"] != str(app_id):
                     store_asset_dict["asset_value"] = 0
                 if self.get_asset_check_code(store_asset_dict["id_md5"], store_asset_dict["asset_value"], app_id) != store_asset_dict["asset_check_code"]:
@@ -803,7 +804,7 @@ class AssetBaseModel():
         store_asset_dict_list = store_asset_model.get_dict_list(condition_where.to_string(), params=params_list)
         if len(store_asset_dict_list) > 0:
             for store_asset_dict in store_asset_dict_list:
-                if config.get_value("is_check_asset",True) == True: #是否开启资产校验
+                if share_config.get_value("is_check_asset",True) == True: #是否开启资产校验
                     if self.get_asset_check_code(store_asset_dict["id_md5"], store_asset_dict["asset_value"], store_asset_dict["app_id"]) != store_asset_dict["asset_check_code"]:
                         store_asset_dict["asset_value"] = 0
         return store_asset_dict_list
