@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-03-06 23:17:54
-@LastEditTime: 2023-02-01 15:42:13
+@LastEditTime: 2023-02-10 10:32:18
 @LastEditors: HuangJianYi
 :Description: 数据缓存业务模型
 """
@@ -11,7 +11,7 @@ from copy import deepcopy
 from seven_framework.base_model import *
 from seven_framework import *
 from seven_framework.redis import *
-
+from seven_cloudapp_frame.libs.common import *
 
 class CacheModel(BaseModel):
 
@@ -115,14 +115,14 @@ class CacheModel(BaseModel):
         :return: 
         :last_editors: HuangJianYi
         """
-        is_cache_empty = config.get_value("is_cache_empty",False)
+        is_cache_empty = share_config.get_value("is_cache_empty",False)
         if is_cache_empty == False:
             if not value:
                 return
         redis_init = self.__redis_init()
         dependency_date_value = redis_init.get(dependency_key)
         if not dependency_date_value:
-            redis_init.set(dependency_key,str(TimeHelper.get_now_format_time()),ex=config.get_value("dependency_cache_expire",5*60*60))
+            redis_init.set(dependency_key,str(TimeHelper.get_now_format_time()),ex=share_config.get_value("dependency_cache_expire",5*60*60))
         dependency_cache_key = self.get_dependency_cache_key(dependency_key,cache_key)
         redis_init.set(dependency_cache_key + "_savetime",str(TimeHelper.get_now_format_time()),ex=cache_expire)
         return redis_init.set(dependency_cache_key,JsonHelper.json_dumps(value),ex=cache_expire)
@@ -202,7 +202,7 @@ class CacheModel(BaseModel):
         dependency_key = self.get_dependency_key(str(dependency_key))
         cache_key = self.get_cache_key('entitylist',field,where,group_by,order_by,limit,params)
         list_row = self.get_dependency_cache(dependency_key,cache_key)
-        if list_row and config.get_value("is_redis_cache",True) == True:
+        if list_row and share_config.get_value("is_redis_cache",True) == True:
             if list_row == 'null':
                 return None
             return self._BaseModel__row_entity_list(list_row)
@@ -211,7 +211,7 @@ class CacheModel(BaseModel):
             cache_value = deepcopy(list_row)
             if not cache_value:
                 cache_value = None
-            config_cache_expire = config.get_value("cache_expire",0)
+            config_cache_expire = share_config.get_value("cache_expire",0)
             if config_cache_expire > 0:
                 cache_expire = config_cache_expire
             self.set_dependency_cache(dependency_key,cache_key,cache_value,cache_expire)
@@ -249,7 +249,7 @@ class CacheModel(BaseModel):
         dependency_key = self.get_dependency_key(str(dependency_key))
         cache_key = self.get_cache_key('entitypagelist',field,where,group_by,order_by,limit,params)
         page_list = self.get_dependency_cache(dependency_key,cache_key)
-        if page_list and config.get_value("is_redis_cache",True) == True:
+        if page_list and share_config.get_value("is_redis_cache",True) == True:
             if page_count_mode == "total":
                 return self._BaseModel__row_entity_list(page_list["data"]),page_list["row_count"]
             elif page_count_mode == "next":
@@ -310,13 +310,13 @@ class CacheModel(BaseModel):
         dependency_key = self.get_dependency_key(str(dependency_key))
         cache_key = self.get_cache_key('entity','*',where,group_by,order_by,'1',params)
         one_row = self.get_dependency_cache(dependency_key,cache_key)
-        if one_row and config.get_value("is_redis_cache",True) == True:
+        if one_row and share_config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
                 return None
             return self._BaseModel__row_entity(one_row)
         else:
             one_row = self.db.fetch_one_row(sql, params)
-            config_cache_expire = config.get_value("cache_expire",0)
+            config_cache_expire = share_config.get_value("cache_expire",0)
             if config_cache_expire > 0:
                 cache_expire = config_cache_expire
             self.set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
@@ -338,13 +338,13 @@ class CacheModel(BaseModel):
         dependency_key = self.get_dependency_key(str(dependency_key))
         cache_key = self.get_cache_key('entityone','*',where,'','','',params)
         one_row = self.get_dependency_cache(dependency_key,cache_key)
-        if one_row and config.get_value("is_redis_cache",True) == True:
+        if one_row and share_config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
                 return None
             return self._BaseModel__row_entity(one_row)
         else:
             one_row = self.db.fetch_one_row(sql,params)
-            config_cache_expire = config.get_value("cache_expire",0)
+            config_cache_expire = share_config.get_value("cache_expire",0)
             if config_cache_expire > 0:
                 cache_expire = config_cache_expire
             self.set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
@@ -373,7 +373,7 @@ class CacheModel(BaseModel):
         dependency_key = self.get_dependency_key(str(dependency_key))
         cache_key = self.get_cache_key('total',field,where,group_by,'','',params)
         total = self.get_dependency_cache(dependency_key,cache_key)
-        if total and config.get_value("is_redis_cache",True) == True:
+        if total and share_config.get_value("is_redis_cache",True) == True:
             if total == '0':
                 return 0
             else:
@@ -381,7 +381,7 @@ class CacheModel(BaseModel):
         else:
             list_row = self.db.fetch_one_row(sql, params)
             if list_row and 'count' in list_row:
-                config_cache_expire = config.get_value("cache_expire",0)
+                config_cache_expire = share_config.get_value("cache_expire",0)
                 if config_cache_expire > 0:
                     cache_expire = config_cache_expire
                 self.set_dependency_cache(dependency_key,cache_key,list_row['count'],cache_expire)
@@ -418,13 +418,13 @@ class CacheModel(BaseModel):
         cache_key = self.get_cache_key('dict',field,where,group_by,order_by,limit,params)
         one_row = self.get_dependency_cache(dependency_key,cache_key)
 
-        if one_row and config.get_value("is_redis_cache",True) == True:
+        if one_row and share_config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
                 return None
             return one_row
         else:
             one_row = self.db.fetch_one_row(sql, params)
-            config_cache_expire = config.get_value("cache_expire",0)
+            config_cache_expire = share_config.get_value("cache_expire",0)
             if config_cache_expire > 0:
                 cache_expire = config_cache_expire
             self.set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
@@ -450,13 +450,13 @@ class CacheModel(BaseModel):
         dependency_key = self.get_dependency_key(str(dependency_key))
         cache_key = self.get_cache_key('dictone',field,where,'','','',params)
         one_row = self.get_dependency_cache(dependency_key,cache_key)
-        if one_row and config.get_value("is_redis_cache",True) == True:
+        if one_row and share_config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
                 return None
             return one_row
         else:
             one_row = self.db.fetch_one_row(sql,params)
-            config_cache_expire = config.get_value("cache_expire",0)
+            config_cache_expire = share_config.get_value("cache_expire",0)
             if config_cache_expire > 0:
                 cache_expire = config_cache_expire
             self.set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
@@ -492,13 +492,13 @@ class CacheModel(BaseModel):
         dependency_key = self.get_dependency_key(str(dependency_key))
         cache_key = self.get_cache_key('dictlist',field,where,group_by,order_by,limit,params)
         list = self.get_dependency_cache(dependency_key,cache_key)
-        if list and config.get_value("is_redis_cache",True) == True:
+        if list and share_config.get_value("is_redis_cache",True) == True:
             return list
         else:
             list_row = self.db.fetch_all_rows(sql, params)
             if not list_row:
                 list_row = []
-            config_cache_expire = config.get_value("cache_expire",0)
+            config_cache_expire = share_config.get_value("cache_expire",0)
             if config_cache_expire > 0:
                 cache_expire = config_cache_expire
             self.set_dependency_cache(dependency_key,cache_key,list_row,cache_expire)
@@ -540,7 +540,7 @@ class CacheModel(BaseModel):
         dependency_key = self.get_dependency_key(str(dependency_key))
         cache_key = self.get_cache_key('dictpagelist',field,where,group_by,order_by,limit,params)
         page_list = self.get_dependency_cache(dependency_key,cache_key)
-        if page_list and config.get_value("is_redis_cache",True) == True:
+        if page_list and share_config.get_value("is_redis_cache",True) == True:
             if page_count_mode == "total":
                 return page_list["data"],page_list["row_count"]
             elif page_count_mode == "next":
@@ -548,7 +548,7 @@ class CacheModel(BaseModel):
             else:
                 return page_list["data"]
         else:
-            config_cache_expire = config.get_value("cache_expire",0)
+            config_cache_expire = share_config.get_value("cache_expire",0)
             if config_cache_expire > 0:
                 cache_expire = config_cache_expire
             page_list = {}
