@@ -2,11 +2,12 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2022-08-25 16:15:20
+@LastEditTime: 2023-02-10 10:42:46
 @LastEditors: HuangJianYi
 @Description: 
 """
 import threading, multiprocessing
+from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.models.seven_model import InvokeResultData
 from seven_framework import *
 from seven_framework.console.base_console import *
@@ -44,7 +45,7 @@ class TimingWork():
         :last_editors: HuangJianYi
         """
         self.work_name = work_name
-        job_config = config.get_value("job_config",{})
+        job_config = share_config.get_value("job_config", {})
         content_dict = job_config.get(work_name,None)
         if content_dict:
             self.start_hours = content_dict.get("start_hours",0)
