@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-06-02 14:32:40
-@LastEditTime: 2022-10-27 17:29:10
+@LastEditTime: 2023-01-04 09:13:12
 @LastEditors: HuangJianYi
 :description: 枚举类
 """
@@ -10,6 +10,15 @@
 from enum import Enum
 from enum import unique
 
+@unique
+class PageCountMode(Enum):
+    """
+    :description: 分页模式
+    """
+    none = 0 #无
+    total = 1 #总数
+    next = 2 #是否有下一页
+
 @unique
 class OperationType(Enum):
     """
