@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 09:44:36
-@LastEditTime: 2022-10-17 14:07:22
+@LastEditTime: 2023-01-04 17:46:27
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -115,7 +115,7 @@ class IpBaseModel():
         self._delete_ip_info_dependency_key(act_id,ip_info.id)
         return invoke_result_data
 
-    def get_ip_info_list(self, app_id, act_id, page_size, page_index, is_del=0,is_release=-1, field="*", condition="", params=[], order_by="sort_index desc", is_cache=True):
+    def get_ip_info_list(self, app_id, act_id, page_size, page_index, is_del=0,is_release=-1, field="*", condition="", params=[], order_by="sort_index desc", is_cache=True, page_count_mode="total"):
         """
         :description: 获取IP列表
         :param app_id：应用标识
@@ -129,6 +129,7 @@ class IpBaseModel():
         :param params：参数数组
         :param order_by：排序
         :param is_cache：是否缓存
+        :param page_count_mode: 分页计数模式 total-计算总数(默认) next-计算是否有下一页(bool) none-不计算
         :return: list
         :last_editors: HuangJianYi
         """
@@ -145,10 +146,10 @@ class IpBaseModel():
             condition_where.add_condition("is_release=%s")
             params_list.append(is_release)
         if is_cache == True:
-            page_list, total = IpInfoModel(context=self.context).get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, dependency_key=DependencyKey.ip_info_list(act_id), cache_expire=600)
+            page_list = IpInfoModel(context=self.context).get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, dependency_key=DependencyKey.ip_info_list(act_id), cache_expire=600, page_count_mode=page_count_mode)
         else:
-            page_list, total = IpInfoModel(context=self.context).get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list)
-        return page_list, total
+            page_list = IpInfoModel(context=self.context).get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, page_count_mode=page_count_mode)
+        return page_list
 
     def update_ip_info_status(self,app_id,ip_id,is_del):
         """
@@ -252,7 +253,7 @@ class IpBaseModel():
         self._delete_ip_type_dependency_key(act_id,ip_type.id)
         return invoke_result_data
 
-    def get_ip_type_list(self, app_id, act_id, page_size, page_index,is_release=-1, field="*", condition="", params=[], order_by="sort_index desc", is_cache=True):
+    def get_ip_type_list(self, app_id, act_id, page_size, page_index,is_release=-1, field="*", condition="", params=[], order_by="sort_index desc", is_cache=True, page_count_mode="total"):
         """
         :description: 获取IP类型列表
         :param app_id：应用标识
@@ -265,7 +266,8 @@ class IpBaseModel():
         :param params：参数数组
         :param order_by：排序
         :param is_cache：是否缓存
-        :return: list
+        :param page_count_mode: 分页计数模式 total-计算总数(默认) next-计算是否有下一页(bool) none-不计算
+        :return:
         :last_editors: HuangJianYi
         """
         params_list = [app_id, act_id]
@@ -278,10 +280,10 @@ class IpBaseModel():
             condition_where.add_condition("is_release=%s")
             params_list.append(is_release)
         if is_cache == True:
-            page_list, total = IpTypeModel(context=self.context).get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, dependency_key=DependencyKey.ip_type_list(act_id), cache_expire=600)
+            page_list = IpTypeModel(context=self.context).get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, dependency_key=DependencyKey.ip_type_list(act_id), cache_expire=600, page_count_mode=page_count_mode)
         else:
-            page_list, total = IpTypeModel(context=self.context).get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list)
-        return page_list, total
+            page_list = IpTypeModel(context=self.context).get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, page_count_mode=page_count_mode)
+        return page_list
 
     def release_ip_type(self,app_id, ip_type_id, is_release):
         """
