@@ -2,12 +2,12 @@
 """
 @Author: HuangJianYi
 @Date: 2021-12-20 16:07:52
-@LastEditTime: 2022-12-21 09:08:48
+@LastEditTime: 2023-02-10 10:36:41
 @LastEditors: HuangJianYi
 @Description: 中台接口相关处理业务模型
 """
 from seven_framework import *
-
+from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.libs.customize.seven_helper import SevenHelper
 
 class MPBaseModel():
@@ -32,12 +32,12 @@ class MPBaseModel():
             return public_function_list
         #产品id
         product_id = config.get_value("project_name")
-        power_project_id = config.get_value("power_project_id") # 权限产品id,SaaS走project_name,SaaS定制走power_project_id
+        power_project_id = share_config.get_value("power_project_id") # 权限产品id,SaaS走project_name,SaaS定制走power_project_id
         if power_project_id:
             product_id = power_project_id
         if not product_id:
             return public_function_list
-        requst_url = config.get_value("mp_url","http://taobao-mp-s.gao7.com") + "/general/project_code_list"
+        requst_url = share_config.get_value("mp_url","http://taobao-mp-s.gao7.com") + "/general/project_code_list"
         data = {}
         data["project_code"] = project_code
         data["product_id"] = product_id
@@ -58,12 +58,12 @@ class MPBaseModel():
         custom_function_list = []
         #产品id
         product_id = config.get_value("project_name")
-        power_project_id = config.get_value("power_project_id") # 权限产品id,SaaS走project_name,SaaS定制走power_project_id
+        power_project_id = share_config.get_value("power_project_id") # 权限产品id,SaaS走project_name,SaaS定制走power_project_id
         if power_project_id:
             product_id = power_project_id
         if not product_id:
             return custom_function_list
-        requst_url = config.get_value("mp_url", "http://taobao-mp-s.gao7.com") + "/custom/query_skin_managemen_list"
+        requst_url = share_config.get_value("mp_url", "http://taobao-mp-s.gao7.com") + "/custom/query_skin_managemen_list"
         data = {}
         data["product_id"] = product_id
         data["store_user_nick"] = store_user_nick
@@ -87,12 +87,12 @@ class MPBaseModel():
         power_list = []
         #产品id
         product_id = config.get_value("project_name")
-        power_project_id = config.get_value("power_project_id") # 权限产品id,SaaS走project_name,SaaS定制走power_project_id
+        power_project_id = share_config.get_value("power_project_id") # 权限产品id,SaaS走project_name,SaaS定制走power_project_id
         if power_project_id:
             product_id = power_project_id
         if not product_id:
             return power_list
-        requst_url = config.get_value("mp_url", "http://taobao-mp-s.gao7.com") + "/general/jurisdiction_list"
+        requst_url = share_config.get_value("mp_url", "http://taobao-mp-s.gao7.com") + "/general/jurisdiction_list"
         data = {}
         data["product_id"] = product_id
         data["project_code"] = project_code
