@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2023-02-06 15:26:37
+@LastEditTime: 2023-02-10 10:45:31
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -86,8 +86,11 @@ class OrderBaseModel(FrameBaseModel):
         """
         page_list = []
 
-        where = "app_id=%s and act_id=%s"
-        params_list = [app_id,act_id]
+        where = "app_id=%s"
+        params_list = [app_id]
+        if act_id >= 0:
+            where += " AND act_id=%s"
+            params_list.append(act_id)
         if condition:
             where += " AND " + condition
             params_list.extend(params)
@@ -464,7 +467,7 @@ class OrderBaseModel(FrameBaseModel):
             return invoke_result_data
         #用户奖品列表
         if len(prize_ids_list)>0:
-            prize_roster_list = prize_roster_model.get_list("act_id=%s and id in (" + prize_ids + ") and prize_status=0",params=[act_id])
+            prize_roster_list = prize_roster_model.get_list("act_id=%s and user_id=%s and id in (" + prize_ids + ") and prize_status=0",params=[act_id, user_id])
             if len(prize_roster_list) == 0:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
@@ -472,7 +475,7 @@ class OrderBaseModel(FrameBaseModel):
                 SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                 return invoke_result_data
         else:
-            prize_roster_list = prize_roster_model.get_list("act_id=%s and prize_status=0",params=[act_id])
+            prize_roster_list = prize_roster_model.get_list("act_id=%s and user_id=%s and prize_status=0",params=[act_id, user_id])
 
         now_date = SevenHelper.get_now_datetime()
         prize_order = PrizeOrder()
@@ -814,14 +817,14 @@ class OrderBaseModel(FrameBaseModel):
         :return:
         :last_editors: HuangJianYi
         """
-        return_info = []
-        where = "app_id=%s AND act_id=%s"
-        params_list = [app_id,act_id]
+        where = "app_id=%s"
+        params_list = [app_id]
+        if act_id >= 0:
+            where += " AND act_id=%s"
+            params_list.append(act_id)
         if condition:
             where += " AND " + condition
             params_list.extend(params)
-        if not app_id or not act_id:
-            return return_info
         if module_id:
             where += " AND module_id=%s"
             params_list.append(module_id)
@@ -1129,7 +1132,7 @@ class OrderBaseModel(FrameBaseModel):
             return invoke_result_data
         
         if source_type != 1:
-            wechat_pay = config.get_value("wechat_pay")
+            wechat_pay = share_config.get_value("wechat_pay")
             #退款异步通知地址
             notify_url = wechat_pay["notify_url"]
             result_data = WeChatPayRequest().create_refund(refund_no, pay_order.pay_order_no, notify_url, refund_amount, pay_order.pay_amount)
