@@ -2,12 +2,13 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 09:39:08
-@LastEditTime: 2022-11-24 19:09:17
+@LastEditTime: 2023-02-10 09:32:11
 @LastEditors: HuangJianYi
 @Description: 
 """
 from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
+from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.models.frame_base_model import FrameBaseModel
 from seven_cloudapp_frame.models.db_models.stat.stat_queue_model import *
 from seven_cloudapp_frame.models.db_models.stat.stat_report_model import *
@@ -48,7 +49,7 @@ class StatBaseModel(FrameBaseModel):
         stat_queue.process_date = SevenHelper.get_now_datetime()
         
         redis_init = SevenHelper.redis_init()
-        stat_process_ways = config.get_value("stat_process_ways","mysql")
+        stat_process_ways = share_config.get_value("stat_process_ways","redis")
         if stat_process_ways == "mysql":
             stat_queue_model = StatQueueModel(context=self.context)
             id = stat_queue_model.add_entity(stat_queue)
@@ -99,7 +100,7 @@ class StatBaseModel(FrameBaseModel):
                 stat_queue.process_date = SevenHelper.get_now_datetime()
                 stat_queue_list.append(stat_queue)
 
-        stat_process_ways = config.get_value("stat_process_ways","mysql")
+        stat_process_ways = share_config.get_value("stat_process_ways","redis")
         if stat_process_ways == "mysql":
             stat_queue_model = StatQueueModel(context=self.context)
             return stat_queue_model.add_list(stat_queue_list)
