@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2022-07-08 10:06:42
+@LastEditTime: 2023-01-16 11:08:01
 @LastEditors: HuangJianYi
 :Description: 基础路由   业务方可以直接使用语句 handlers.extend(seven_cloudapp_frame.route.seven_cloudapp_frame_route()) 引入
 """
@@ -37,7 +37,7 @@ def seven_cloudapp_frame_route():
         (r"/client/save_skin", theme.SaveSkinHandler),  #保存皮肤信息，由前端通过工具进行保存
         (r"/client/theme_info_list", theme.ThemeInfoListHandler),  #主题列表
         (r"/client/skin_info_list", theme.SkinInfoListHandler),  #皮肤列表
-        (r"/client/ip_info_list", ip.IpInfoListHandler),  #ip信息列表
+        (r"/client/ip_info_list", ip_c.IpInfoListHandler),  #ip信息列表
         (r"/client/act_info", act.ActInfoHandler),  #活动信息
         (r"/client/act_prize_list", act.ActPrizeListHandler),  #活动奖品列表
         (r"/client/cms_info_list", act.CmsInfoListHandler),  #位置信息列表
